@@ -65,7 +65,7 @@ private Q_SLOTS:
         FakeServer fakeServer;
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
-        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
+        KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
         KIMAP::CreateJob *job = new KIMAP::CreateJob(&session);
         job->setMailBox(mailbox);
