@@ -22,18 +22,13 @@
 #include "message_p.h"
 #include "session_p.h"
 
+#include <KLocalizedString>
 #include "kimap_debug.h"
 
-using namespace KIMAP2;
-
-void JobPrivate::sendCommand(const QByteArray &command, const QByteArray &args)
-{
-    tags << sessionInternal()->sendCommand(command, args);
-    m_currentCommand = command + "" + args;
-}
+using namespace KIMAP;
 
 Job::Job(Session *session)
-    : KJob(session), d_ptr(new JobPrivate(session, "Job"))
+    : KJob(session), d_ptr(new JobPrivate(session, i18n("Job")))
 {
 }
 
@@ -66,36 +61,29 @@ void Job::handleResponse(const Message &response)
 
 void Job::connectionLost()
 {
-    Q_D(Job);
-    setError(ConnectionLost);
-    setErrorText("Connection to server lost: " + d->m_errorMessage);
+    setError(KJob::UserDefinedError);
+    setErrorText(i18n("Connection to server lost."));
     emitResult();
 }
 
-void Job::setSocketError(QAbstractSocket::SocketError error)
+void Job::setSocketError(KTcpSocket::Error error)
 {
     Q_D(Job);
     d->m_socketError = error;
 }
 
-void Job::setErrorMessage(const QString &msg)
-{
-    Q_D(Job);
-    d->m_errorMessage = msg;
-}
-
 Job::HandlerResponse Job::handleErrorReplies(const Message &response)
 {
     Q_D(Job);
-    // qCDebug(KIMAP2_LOG) << response.toString();
+//   qCDebug(KIMAP_LOG) << response.toString();
 
     if (!response.content.isEmpty() &&
             d->tags.contains(response.content.first().toString())) {
         if (response.content.size() < 2) {
-            setErrorText(QString("%1 failed, malformed reply from the server.").arg(d->m_name));
+            setErrorText(i18n("%1 failed, malformed reply from the server.", d->m_name));
         } else if (response.content[1].toString() != "OK") {
-            setError(CommandFailed);
-            setErrorText(QString("%1 failed, server replied: %2.\n Sent command: %3").arg(d->m_name).arg(QLatin1String(response.toString().constData())).arg(QString(d->m_currentCommand)));
+            setError(UserDefinedError);
+            setErrorText(i18n("%1 failed, server replied: %2", d->m_name, QLatin1String(response.toString().constData())));
         }
         d->tags.removeAll(response.content.first().toString());
         if (d->tags.isEmpty()) {   // Only emit result when the last command returned
